# humanize

Welcome to the humanize API reference.

* [Number](number)
* [Time](time)
* [Filesize](filesize)
* [I18n](i18n)

{%
   include-markdown "../README.md"
   start="<!-- usage-start -->"
   end="<!-- usage-end -->"
   comments=false
%}
